==> aws-cdk-lib-2.0.0-rc.6-sources.jar: software/amazon/awscdk/services/codedeploy/EcsDeploymentConfig.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * (experimental) A custom Deployment Configuration for an ECS Deployment Group.
 * <p>
 * Note: This class currently stands as namespaced container of the default configurations
 * until CloudFormation supports custom ECS Deployment Configs. Until then it is closed
 * (private constructor) and does not extend {&#64;link Construct}
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-06-02T09:55:07.360Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_codedeploy.EcsDeploymentConfig")
public class EcsDeploymentConfig extends software.amazon.jsii.JsiiObject {

    protected EcsDeploymentConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected EcsDeploymentConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ALL_AT_ONCE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.EcsDeploymentConfig.class, "ALL_AT_ONCE", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.IEcsDeploymentConfig.class));
    }

    /**
     * (experimental) Import a custom Deployment Configuration for an ECS Deployment Group defined outside the CDK.
     * <p>
     * @return a Construct representing a reference to an existing custom Deployment Configuration
     * @param _scope the parent Construct for this new Construct. This parameter is required.
     * @param _id the logical ID of this new Construct. This parameter is required.
     * @param ecsDeploymentConfigName the name of the referenced custom Deployment Configuration. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codedeploy.IEcsDeploymentConfig fromEcsDeploymentConfigName(final @org.jetbrains.annotations.NotNull software.constructs.Construct _scope, final @org.jetbrains.annotations.NotNull java.lang.String _id, final @org.jetbrains.annotations.NotNull java.lang.String ecsDeploymentConfigName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codedeploy.EcsDeploymentConfig.class, "fromEcsDeploymentConfigName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.IEcsDeploymentConfig.class), new Object[] { java.util.Objects.requireNonNull(_scope, "_scope is required"), java.util.Objects.requireNonNull(_id, "_id is required"), java.util.Objects.requireNonNull(ecsDeploymentConfigName, "ecsDeploymentConfigName is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.codedeploy.IEcsDeploymentConfig ALL_AT_ONCE;
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/codedeploy/EcsDeploymentConfig.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * A custom Deployment Configuration for an ECS Deployment Group.
 * <p>
 * Note: This class currently stands as namespaced container of the default configurations
 * until CloudFormation supports custom ECS Deployment Configs. Until then it is closed
 * (private constructor) and does not extend {&#64;link Construct}
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:08.319Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_codedeploy.EcsDeploymentConfig")
public class EcsDeploymentConfig extends software.amazon.jsii.JsiiObject {

    protected EcsDeploymentConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected EcsDeploymentConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ALL_AT_ONCE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.EcsDeploymentConfig.class, "ALL_AT_ONCE", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.IEcsDeploymentConfig.class));
    }

    /**
     * Import a custom Deployment Configuration for an ECS Deployment Group defined outside the CDK.
     * <p>
     * @return a Construct representing a reference to an existing custom Deployment Configuration
     * @param _scope the parent Construct for this new Construct. This parameter is required.
     * @param _id the logical ID of this new Construct. This parameter is required.
     * @param ecsDeploymentConfigName the name of the referenced custom Deployment Configuration. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codedeploy.IEcsDeploymentConfig fromEcsDeploymentConfigName(final @org.jetbrains.annotations.NotNull software.constructs.Construct _scope, final @org.jetbrains.annotations.NotNull java.lang.String _id, final @org.jetbrains.annotations.NotNull java.lang.String ecsDeploymentConfigName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codedeploy.EcsDeploymentConfig.class, "fromEcsDeploymentConfigName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.IEcsDeploymentConfig.class), new Object[] { java.util.Objects.requireNonNull(_scope, "_scope is required"), java.util.Objects.requireNonNull(_id, "_id is required"), java.util.Objects.requireNonNull(ecsDeploymentConfigName, "ecsDeploymentConfigName is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IEcsDeploymentConfig ALL_AT_ONCE;
}
